@@ -3,8 +3,8 @@
 
 ;; URL: https://github.com/gcv/julia-snail
 ;; Package-Requires: ((emacs "26.2") (dash "2.16.0") (julia-mode "0.3") (s "1.12.0") (spinner "1.7.3") (popup "0.5.9"))
-;; Package-Version: 20250910.703
-;; Package-Revision: 7b50882f5aec
+;; Package-Version: 20251211.2305
+;; Package-Revision: 5a7e2d479c5c
 ;; Created: 2019-10-27
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -585,7 +585,7 @@ Returns nil if the poll timed out, t otherwise."
         (cl-loop for f in julia-snail--julia-files do
                  (if (file-directory-p f)
                      (make-directory (concat snail-remote-dir f))
-                   (copy-file f (concat snail-remote-dir (file-name-directory f)) t)))))
+                   (copy-file (file-truename f) (concat snail-remote-dir (file-name-directory f)) t)))))
     snail-remote-dir))
 
 (defun julia-snail--launch-command ()
